==> glooxd-0.2.1.tar.bz2: glooxd-0.2.1/src/featurecompression.cpp <==
/*
  Copyright (c) 2009 by Jakob Schroeter <js@camaya.net>
  This file is part of the glooxd library. http://camaya.net/glooxd

  This software is distributed under a license. The full license
  agreement can be found in the file LICENSE in this distribution.
  This software may not be copied, modified, sold or distributed
  other than expressed in the named license agreement.

  This software is distributed without any warranty.
*/


#include "client.h"
#include "connectioncompression.h"
#include "featurecompression.h"

#include <gloox/gloox.h>

namespace glooxd
{

  FeatureCompression::FeatureCompression()
    : m_state( ZlibCanceled )
  {
  }

  const std::string& FeatureCompression::filterString() const
  {
    static const std::string filter = "/compress[@xmlns='" + gloox::XMLNS_COMPRESSION + "']";
    return filter;
  }

  gloox::Tag* FeatureCompression::tag( int state, const std::string& /*domain*/ )
  {
    gloox::Tag* t = 0;
    if( ( state & StateTLS ) == StateTLS
          && ( state & StateAuthentication ) != StateAuthentication
          && ( state & StateCompression ) != StateCompression )
    {
      t = new gloox::Tag( "compression" );
      t->setXmlns( gloox::XMLNS_STREAM_COMPRESS );
      new gloox::Tag( t, "method", "zlib" );

      m_state = ZlibOffered;
    }

    return t;
  }

  void FeatureCompression::handleTag( gloox::Tag* _tag )
  {
    if( !_tag || _tag->xmlns() != gloox::XMLNS_COMPRESSION )
      return;

    const std::string& name = _tag->name();

    if( _tag->findCData( "/compress/method" ) == "zlib" )
    {
      gloox::Tag* c = new gloox::Tag( "compressed" );
      c->setXmlns( gloox::XMLNS_COMPRESSION );
      m_parent->send( c );

      gloox::ConnectionCompression* compression = new gloox::ConnectionCompression( m_parent,
          m_parent->connection(), m_parent->logInstance() );
      compression->connect();
      m_parent->finishStreamFeature( StateReset, compression );
      m_parent->finishStreamFeature( StateCompression );
      m_state = ZlibEnabled;
    }
    else if( name == "failure" )
    {
      m_state = ZlibCanceled;
      m_parent->disconnect( gloox::ConnCompressionFailed );
    }
  }

}

==> glooxd-0.2.4.tar.bz2: glooxd-0.2.4/src/featurecompression.cpp <==
/*
  Copyright (c) 2009 by Jakob Schroeter <js@camaya.net>
  This file is part of the glooxd library. http://camaya.net/glooxd

  This software is distributed under a license. The full license
  agreement can be found in the file LICENSE in this distribution.
  This software may not be copied, modified, sold or distributed
  other than expressed in the named license agreement.

  This software is distributed without any warranty.
*/


#include "client.h"
#include "connectioncompression.h"
#include "featurecompression.h"

#include <gloox/gloox.h>

namespace glooxd
{

  FeatureCompression::FeatureCompression()
    : m_state( ZlibCanceled )
  {
  }

  const std::string& FeatureCompression::filterString() const
  {
    static const std::string filter = "/compress[@xmlns='" + gloox::XMLNS_COMPRESSION + "']";
    return filter;
  }

  gloox::Tag* FeatureCompression::tag( int state, const std::string& /*domain*/ )
  {
    gloox::Tag* t = 0;
    if( ( state & StateTLS ) == StateTLS
          && ( state & StateAuthentication ) != StateAuthentication
          && ( state & StateCompression ) != StateCompression )
    {
      t = new gloox::Tag( "compression" );
      t->setXmlns( gloox::XMLNS_STREAM_COMPRESS );
      new gloox::Tag( t, "method", "zlib" );

      m_state = ZlibOffered;
    }

    return t;
  }

  void FeatureCompression::handleTag( gloox::Tag* _tag )
  {
    if( !_tag || _tag->xmlns() != gloox::XMLNS_COMPRESSION )
      return;

    const std::string& name = _tag->name();

    if( _tag->findCData( "/compress/method" ) == "zlib" )
    {
      gloox::Tag* c = new gloox::Tag( "compressed" );
      c->setXmlns( gloox::XMLNS_COMPRESSION );
      m_parent->send( c );

      ConnectionCompression* compression = new ConnectionCompression( m_parent,
          m_parent->connection(), m_parent->logInstance() );
      compression->connect();
      m_parent->finishStreamFeature( StateReset, compression );
      m_parent->finishStreamFeature( StateCompression );
      m_state = ZlibEnabled;
    }
    else if( name == "failure" )
    {
      m_state = ZlibCanceled;
      m_parent->disconnect( gloox::ConnCompressionFailed );
    }
  }

}
